@@ -23,7 +23,7 @@ ACTIONS = (
     'clean',
     'time-upload',
     'time-download',
-    'time-sql',
+    'ab',
 )
 MULTIPART_THREHOLD = 64 * 2**20
 MULTIPART_CHUNKSIZE = 8 * 2**20
@@ -259,6 +259,7 @@ class Controller:
         self.subparser.add_argument('--storage-class', required=False)
         self.subparser.add_argument('--object-size', type=int, required=True)
         self.subparser.add_argument('--object-number', type=int, required=True)
+        self.subparser.add_argument('--object-prefix', required=False)
         self.subparser.add_argument('--multipart-threshold', type=int, default=MULTIPART_THREHOLD)
         self.subparser.add_argument('--multipart-chunksize', type=int, default=MULTIPART_CHUNKSIZE)
         self.subparser.add_argument('--max-concurrency', type=int, default=MAX_CONCURRENCY)
@@ -269,6 +270,7 @@ class Controller:
             storage_class=parsed_args.storage_class,
             object_size=parsed_args.object_size,
             object_number=parsed_args.object_number,
+            object_prefix=parsed_args.object_prefix,
             multipart_threshold=parsed_args.multipart_threshold,
             multipart_chunksize=parsed_args.multipart_chunksize,
             max_concurrency=parsed_args.max_concurrency,
@@ -283,6 +285,8 @@ class Controller:
         self.subparser.add_argument('--storage-class', required=False)
         self.subparser.add_argument('--object-size', type=int, required=False)
         self.subparser.add_argument('--object-number', type=int, required=False)
+        self.subparser.add_argument('--object-prefix', required=False)
+        self.subparser.add_argument('--presigned', action="store_true")
         parsed_args = self.parser.parse_known_args()[0]
 
         benchmark = benchmarks.DownloadBenchmark(self.driver)
@@ -290,6 +294,8 @@ class Controller:
             storage_class=parsed_args.storage_class,
             object_size=parsed_args.object_size,
             object_number=parsed_args.object_number,
+            object_prefix=parsed_args.object_prefix,
+            presigned=parsed_args.presigned,
         )
         benchmark.setup()
         benchmark.run()
@@ -297,22 +303,31 @@ class Controller:
         stats = benchmark.make_stats()
         self.print_stats(stats)
 
-    def time_sql(self):
-        DEFAULT_EXPRESSION = 'SELECT COUNT(*)'
+    def ab(self):
         self.subparser.add_argument('--storage-class', required=False)
-        self.subparser.add_argument('--rows', type=int, required=False)
-        self.subparser.add_argument('--columns', type=str, default='int', required=False)
-        self.subparser.add_argument('--randomseed', type=int, required=False)
-        self.subparser.add_argument('--expression', type=str, default=DEFAULT_EXPRESSION,
-                                    required=False)
+        self.subparser.add_argument('--object-size', type=int, required=False)
+        self.subparser.add_argument('--object-number', type=int, required=False)
+        self.subparser.add_argument('--object-prefix', required=False)
+        self.subparser.add_argument('--presigned', action="store_true")
+        self.subparser.add_argument('--concurrency', type=int, default=1)
+        self.subparser.add_argument('--timelimit', type=int, default=30)
+        self.subparser.add_argument('--num-requests', type=int, default=100)
+        self.subparser.add_argument('--keep-alive', action="store_true")
+        self.subparser.add_argument('--source-address', required=False)
         parsed_args = self.parser.parse_known_args()[0]
 
-        benchmark = benchmarks.SqlBenchmark(self.driver)
+        benchmark = benchmarks.AbBenchmark(self.driver)
         benchmark.set_params(
             storage_class=parsed_args.storage_class,
-            rows=parsed_args.rows,
-            columns=parsed_args.columns,
-            expression=parsed_args.expression,
+            object_size=parsed_args.object_size,
+            object_number=parsed_args.object_number,
+            object_prefix=parsed_args.object_prefix,
+            presigned=parsed_args.presigned,
+            concurrency=parsed_args.concurrency,
+            timelimit=parsed_args.timelimit,
+            num_requests=parsed_args.num_requests,
+            keep_alive=parsed_args.keep_alive,
+            source_address=parsed_args.source_address,
         )
         benchmark.setup()
         benchmark.run()
