@@ -30,5 +30,13 @@ class DriverBucketUnfoundError(DriverError):
     """Driver bucket unfound error"""
 
 
+class DriverBucketAlreadyExistError(DriverError):
+    """Driver bucket already exist error"""
+
+
 class DriverObjectUnfoundError(DriverError):
     """Driver object unfound error"""
+
+
+class DriverStorageQuotaError(DriverError):
+    """Driver service storage quota error"""
